/* ********************************************************************
Description: 
Include header for AICON_Receiver.dll. Include this into your source and the
linker automatically includes the necessary library.

Author:
Marcel Ellerbrok

Revision:
* 09.11.2007 - ME - First stable version
* 21.09.2010 - ME - Added transfer of whole point sets
 **********************************************************************/
#ifndef __AICON_RECEIVER_DATA__
#define __AICON_RECEIVER_DATA__

#if _MSC_VER > 1000
	#pragma once
#endif

// ---------------------------------------------------------------------------
extern "C"
{

// Internally we use a structure packing of 8 bit.
#pragma pack( push, 8)

// ---------------------------------------------------------------------------
#ifndef GUID_DEFINED
#define GUID_DEFINED

	/* ********************************************************************
	Description: 
	Definition of a GUID (General Unique ID). This is needed for the case that
	the default Microsoft headers are not included. MatLab for example.
	******************************************************************** */
	typedef struct {
		unsigned long  Data1;
		unsigned short Data2;
		unsigned short Data3;
		unsigned char  Data4[ 8 ];
	} GUID;

#endif 

const GUID GUID_ZERO = { 0, 0, 0, { 0, 0, 0, 0, 0, 0, 0, 0 } };

/* ********************************************************************
Description: 
This enumeration defines return values for all interface functions. They 
are explained at the function definition.
******************************************************************** */
enum eReturnCodes
{
	// Function processed correctly.
	rcSuccess = 0,
	// Function failed without further specification
	rcFailed,
	// The function gReceiver_Init was never called
	rcNotInitialized,
	// You requested data, but you have not measured yet
	rcNotMeasuredYet,
	// There is no probe connected
	rcNotConnected,
	// The measure mode is wrong
	rcWrongMeasureMode,
	// The connection is already opened
	rcServerAlreadyRunning,
	// The connection was not opened
	rcServerNotRunning,
	// The desired operation is not available
	rcNotAvailable,
	// the current state does not support this command
	rcWrongState,
	// pre orientation step finished
	rcPreOrientationFinished,
	// the data source did not respond
	rcTimeOut,
};

/* ********************************************************************
Description: 
This enumeration defines the state codes of the data
******************************************************************** */
enum eStateCodes
{
	// Data is valid
	stateValid = 1,
};

/* ********************************************************************
Description: 
This enumeration defines the command codes the measuring device may send.
******************************************************************** */
enum eCommandCodes
{
	// Do not perform a special operation
	cmdNoOperation = 0,
	// The user pressed a button at the probe
	cmdButton1,
	cmdButton2,
	// error code
	errMeasurementFailed,
};

/* ********************************************************************
Description: 
This enumeration defines the command codes the measuring device may send.
******************************************************************** */
enum eEventCodes
{
	// We have connected to a data source
	eventConnectionStarted = 0,
	// The connection was terminated
	eventConnectionEnded,
	// We have received data
	eventDataReceived,
	// The live mode was started
	eventLiveMeasurementStarted,
	// The live mode was stopped
	eventLiveMeasurementStopped,
	// The current measure mode was changed
	eventMeasureModeChanged,
	// We have received a calibration result
	eventCalibResultReceived,
	// The current measurement parameters changed e.g. the reference panel
	eventMeasureParamChanged,
	// The MoveInspect project state changed
	eventMIProjectStateChanged,
	// The reference list changed
	eventReferenceListChanged,
};

/* ********************************************************************
Description: 
This enumeration defines the different measure mode types
******************************************************************** */
enum eMeasureModeTypes
{
	mmtMeasurement = 0,
	mmtProject,
	mmtCalibration,
};

/* ********************************************************************
Description: 
Definition of the data receive-callback that you may install. This
callback will always be called after receiving valid data.
******************************************************************** */
typedef void (*tReceiver_EventCallbackPtr)(int, void*);

/************************************************************************
Description:
This structure contains the definition of an RGB color value.
************************************************************************/
typedef struct
{
	unsigned char    uRed;
	unsigned char    uGreen;
	unsigned char    uBlue;
} tRGB;

/************************************************************************
Description:
This structure contains the definition of an image.
************************************************************************/
typedef struct
{
	// Number of image
	int iNumber;

	// size of the image
	unsigned int iWidth;
	unsigned int iHeight;
	unsigned int iPadWidth;
	unsigned int iBitsPerPixel;

	// the color table
	unsigned int   iColorTableSize;
	tRGB*		   pColorTable;

	// buffer of the image
	unsigned int   iPixelBufferSize;
	unsigned char* pPixelBuffer;

	// measure field index
	int   iMeasureFieldIdx;
}tImage;

/************************************************************************
Description:
This structure contains the parameters of the interior orientation of a
camera.
************************************************************************/
typedef struct
{
	// Focal distance in mm
	double dCk;
	// Size of sensor in pixel
	int iSizeX;
	// Size of sensor in pixel
	int iSizeY;
	// Size of sensor in mm
	double dSizeXmm;
	// Size of sensor in mm
	double dSizeYmm;
	// Center point of sensor in mm (0.0 if unknown).
	double dXh;
	// Center point of sensor in mm (0.0 if unknown).
	double dYh;
	// Radial symmetric distortion parameter (0.0 if unknown).
	double dA1;
	// Radial symmetric distortion parameter (0.0 if unknown).
	double dA2;
	// Radial symmetric distortion parameter (0.0 if unknown).
	double dA3;
	// Asymmetric distortion parameter (0.0 if unknown).
	double dB1;
	// Asymmetric distortion parameter (0.0 if unknown).
	double dB2;
	// Affine distortion parameter (0.0 if unknown).
	double dC1;
	// Affine distortion parameter (0.0 if unknown).
	double dC2;
	// Distortion radius.
	double dR0;
}tInteriorOrientation;

/************************************************************************
Description:
This structure contains the definition of a camera.                                                                
************************************************************************/
typedef struct
{
	// Number of camera.
	int iNumber;

	// Exterior orientation in mm.
	double dX;
	double dY;
	double dZ;

	// Orientation angles of exterior orientation in rad.
	double dOm;
	double dPh;
	double dKa;

	// the interior orientation
	tInteriorOrientation cIOR;

	// measure field index
	int   iMeasureFieldIdx;
}tCamera;

/* ********************************************************************
Description: 
A Unicode structure to contain information about a 6DoF object. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
t6DoFA, t6DoF

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro t6DoF that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// number of the point
	int     iNum;
	// name of the point (may be empty)
	wchar_t cName[128];
	// the point was triggered by the user
	bool    bTriggered;
	// the location
	bool    bLocationValid;
	double  dX;
	double  dY;
	double  dZ;
	// the location deviation
	bool    bLocationDeviationValid;
	double  dSx;
	double  dSy;
	double  dSz;
	// the rotation
	bool    bRotationValid;
	double  dO;
	double  dP;
	double  dK;
	// the rotation deviation
	bool    bRotationDeviationValid;
	double  dSo;
	double  dSp;
	double  dSk;
	// measure field index
	int   iMeasureFieldIdx;
	// the quality values ( values < 0 is "not available" )
	bool    bQualityValuesValid;
	double  dVolumePercent;
	double  dSigma0;
	double  dRayPercent;
	int     iRayCount;
}t6DoFU;

/* ********************************************************************
Description: 
A ASCII structure to contain information about a 6DoF object. Use this 
struct if your program runs in ASCII mode. 

SeeAlso:     
t6DoFU, t6DoF

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro t6DoF that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// number of the point
	int    iNum;
	// name of the point (may be empty)
	char   cName[128];
	// the point was triggered by the user
	bool   bTriggered;
	// the location
	bool    bLocationValid;
	double  dX;
	double  dY;
	double  dZ;
	// the location deviation
	bool    bLocationDeviationValid;
	double  dSx;
	double  dSy;
	double  dSz;
	// the rotation
	bool    bRotationValid;
	double  dO;
	double  dP;
	double  dK;
	// the rotation deviation
	bool    bRotationDeviationValid;
	double  dSo;
	double  dSp;
	double  dSk;
	// measure field index
	int   iMeasureFieldIdx;
	// the quality values ( values < 0 is "not available" )
	bool    bQualityValuesValid;
	double  dVolumePercent;
	double  dSigma0;
	double  dRayPercent;
	int     iRayCount;
}t6DoFA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: t6DoFU, t6DoFA
	******************************************************************** */
	#define t6DoF t6DoFU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: t6DoFU, t6DoFA
	******************************************************************** */
	#define t6DoF t6DoFA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information about a adapter object. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
tAdapterA, tAdapter

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tAdapter that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// name of the adapter
	wchar_t cName[128];
	
	// measure field index
	int   iMeasureFieldIdx;

	// the transformation matrix
	double dMatRowCol[4][4];
}tAdapterU;

/* ********************************************************************
Description: 
A ASCII structure to contain information about a adapter object. Use this 
struct if your program runs in ASCII mode. 

SeeAlso:     
t6DoFU, t6DoF

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tAdapter that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// name of the adapter
	char cName[128];

	// measure field index
	int   iMeasureFieldIdx;

	// the transformation matrix
	double dMatRowCol[4][4];
}tAdapterA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tAdapterU, tAdapterA
	******************************************************************** */
	#define tAdapter tAdapterU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tAdapterU, tAdapterA
	******************************************************************** */
	#define tAdapter tAdapterA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information about a received point. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
tPointA, tPoint

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tPoint that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// number of the point
	int     iNum;
	// name of the point (may be empty)
	wchar_t cName[128];
	// the point was triggered by the user
	bool    bTriggered;
	// the point is a probe tip
	bool    bProbeTip;
	// the coordinate of the point
	bool    bCoordValid;
	double  dX;
	double  dY;
	double  dZ;
	// the deviation of this point
	bool    bDeviationValid;
	double  dSx;
	double  dSy;
	double  dSz;
	// the normal vector of this point
	bool    bNormalValid;
	double  dNx;
	double  dNy;
	double  dNz;
	// the number of rays of this point
	bool    bRaysValid;
	int     iRays;
	// measure field index
	int   iMeasureFieldIdx;
}tPointU;

/* ********************************************************************
Description: 
A ASCII structure to contain information about a received point. Use this 
struct if your program runs in ASCII mode. 

SeeAlso:     
tPointU, tPoint

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tPoint that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// number of the point
	int    iNum;
	// name of the point (may be empty)
	char   cName[128];
	// the point was triggered by the user
	bool   bTriggered;
	// the point is a probe tip
	bool    bProbeTip;
	// the coordinate of the point
	bool    bCoordValid;
	double  dX;
	double  dY;
	double  dZ;
	// the deviation of this point
	bool    bDeviationValid;
	double  dSx;
	double  dSy;
	double  dSz;
	// the normal vector of this point
	bool    bNormalValid;
	double  dNx;
	double  dNy;
	double  dNz;
	// the number of rays of this point
	bool    bRaysValid;
	int     iRays;
	// measure field index
	int   iMeasureFieldIdx;
}tPointA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tPointU, tPointA
	******************************************************************** */
	#define tPoint tPointU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tPointU, tPointA
	******************************************************************** */
	#define tPoint tPointA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information about a sensor object. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
tSensorA, tSensor

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro t6DoF that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// number of the sensor
	int     iNum;
	// name of the sensor (may be empty)
	wchar_t cName[128];
	// the value
	double  dValue;
	bool    bValueValid;
	// measure field index
	int   iMeasureFieldIdx;
}tSensorU;

/* ********************************************************************
Description: 
A ASCII structure to contain information about a sensor object. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
tSensorU, tSensor

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro t6DoF that automatically chooses the right type.
******************************************************************** */
typedef struct
{
	// number of the sensor
	int     iNum;
	// name of the sensor (may be empty)
	char cName[128];
	// the value
	double  dValue;
	bool    bValueValid;
	// measure field index
	int   iMeasureFieldIdx;
}tSensorA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tSensorU, tSensorA
	******************************************************************** */
	#define tSensor tSensorU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tSensorU, tSensorA
	******************************************************************** */
	#define tSensor tSensorA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information about any received data. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
cDataA, tData

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tData that automatically chooses the right type.
******************************************************************** */
typedef struct cDataU
{
	public:
		// constructor
		inline cDataU()
		{ 
			iState             = 0;
			iCommand		   = 0;
			dDiameterTip	   = 0.0;
			dDiameterShank	   = 0.0;
			bContainsTriggered = false;
			iEpoch             = -1;
			uPointsCapacity    = 0;
			pvPoints		   = NULL;
			uCameraCapacity    = 0;
			pvCameras		   = NULL;
			u6DoFCapacity      = 0;
			pv6DoF			   = NULL;
			uImageCapacity     = 0;
			pvImages		   = NULL;
			bReferenceQualityValid = false;
			dReferenceVolumePercentage = 0.0;
			dReferenceRayPercentage = 0.0;
			iReferenceRayCnt = 0;
			dReferenceSigma0 = 0.0;
		};

		// The state of the data ( See: eStateCodes )
		int      iState;
		// A special command code ( See: eCommandCodes )
		int      iCommand;
		// The diameter of the current used probe tip
		double   dDiameterTip;
		// The diameter of the current used probe shank
		double   dDiameterShank;
		// A vector containing the received points
		tPointU* pvPoints;
		// The capacity of the points vector
		UINT     uPointsCapacity;
		// pvPoints contains one or more triggered points
		bool	 bContainsTriggered;
		// the epoch number ( -1 if no epoch info is available )
		int		 iEpoch;
		// A vector containing the received cameras
		tCamera* pvCameras;
		// The capacity of the camera vector
		UINT     uCameraCapacity;
		// A vector containing the 6DoF information
		t6DoFU*	 pv6DoF;
		// The capacity of the 6DoF vector
		UINT     u6DoFCapacity;
		// The capacity of the image vector
		UINT     uImageCapacity;
		// A vector containing the image information
		tImage*  pvImages;
		// A vector containing the sensor information
		tSensorU*	 pvSensor;
		// The capacity of the sensor vector
		UINT     uSensorCapacity;
		// The reference quality values are valid
		bool bReferenceQualityValid;

		double dReferenceVolumePercentage;
		double dReferenceRayPercentage;
		int    iReferenceRayCnt;
		double dReferenceSigma0;
} tDataU;

/* ********************************************************************
Description: 
A Unicode structure to contain information about any received data. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
cDataA, tData

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tData that automatically chooses the right type.
******************************************************************** */
typedef struct cDataA
{
	public:
		// constructor
		inline cDataA()
		{
			iState             = 0;
			iCommand		   = 0;
			dDiameterTip	   = 0.0;
			dDiameterShank	   = 0.0;
			bContainsTriggered = false;
			iEpoch             = -1;
			uPointsCapacity    = 0;
			pvPoints		   = NULL;
			uCameraCapacity    = 0;
			pvCameras		   = NULL;
			u6DoFCapacity      = 0;
			pv6DoF			   = NULL;
			uImageCapacity     = 0;
			pvImages           = NULL;
			bReferenceQualityValid = false;
			dReferenceVolumePercentage = 0.0;
			dReferenceRayPercentage = 0.0;
			iReferenceRayCnt = 0;
			dReferenceSigma0 = 0.0;
		};

		// The state of the data ( See: eStateCodes )
		int      iState;
		// A special command code ( See: eCommandCodes )
		int      iCommand;
		// The diameter of the current used probe tip
		double   dDiameterTip;
		// The diameter of the current used probe shank
		double   dDiameterShank;
		// A vector containing the received points
		tPointA* pvPoints;
		// The capacity of the points vector
		UINT     uPointsCapacity;
		// pvPoints contains one or more triggered points
		bool	 bContainsTriggered;
		// the epoch number ( -1 if no epoch info is available )
		int		 iEpoch;
		// A vector containing the received cameras
		tCamera* pvCameras;
		// The capacity of the camera vector
		UINT     uCameraCapacity;
		// A vector containing the 6DoF information
		t6DoFA*	 pv6DoF;
		// The capacity of the 6DoF vector
		UINT     u6DoFCapacity;
		// The capacity of the image vector
		UINT     uImageCapacity;
		// A vector containing the image information
		tImage*  pvImages;
		// A vector containing the sensor information
		tSensorA*	 pvSensor;
		// The capacity of the sensor vector
		UINT     uSensorCapacity;
			// The reference quality values are valid
		bool bReferenceQualityValid;

	 	double dReferenceVolumePercentage;
		double dReferenceRayPercentage;
		int    iReferenceRayCnt;
		double dReferenceSigma0;
} tDataA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: cDataU, cDataA
	******************************************************************** */
	#define tData cDataU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: cDataU, cDataA
	******************************************************************** */
	#define tData cDataA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information a measure mode. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
tMeasureModeInfoA, tMeasureModeInfo

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tMeasureModeInfo that automatically chooses the right 
type.
******************************************************************** */
typedef struct
{
	// identification number of the measure mode
	int     iNum;
	// name of the measure mode
	wchar_t cName[128];
	// measure mode type
	int iModeType;
}tMeasureModeInfoU;

/* ********************************************************************
Description: 
A ASCII structure to contain information a measure mode. Use this 
struct if your program runs in ASCII mode. 

SeeAlso:     
tMeasureModeInfoU, tMeasureModeInfo

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tMeasureModeInfo that automatically chooses the right 
type.
******************************************************************** */
typedef struct
{
	// identification number of the measure mode
	int    iNum;
	// name of the measure mode
	char   cName[128];
	// measure mode type
	int iModeType;
}tMeasureModeInfoA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tMeasureModeInfoU, tMeasureModeInfoA
	******************************************************************** */
	#define tMeasureModeInfo tMeasureModeInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tMeasureModeInfoU, tMeasureModeInfoA
	******************************************************************** */
	#define tMeasureModeInfo tMeasureModeInfoA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information about a data source. Use this 
struct if your program runs in UNICODE mode. 

SeeAlso:     
tDataSourceInfoA, tDataSourceInfo

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tDataSource that automatically chooses the right 
type.
******************************************************************** */
typedef struct
{
	// identification
	GUID cSourceID;
	// name of the data source
	wchar_t cName[128];
}tDataSourceInfoU;

/* ********************************************************************
Description: 
A ASCII structure to contain information a measure mode. Use this 
struct if your program runs in ASCII mode. 

SeeAlso:     
tDataSourceInfoU, tDataSourceInfo

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tMeasureModeInfo that automatically chooses the right 
type.
******************************************************************** */
typedef struct
{
	// identification
	GUID cSourceID;
	// name of the data source
	char cName[128];
}tDataSourceInfoA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tDataSourceInfoU, tDataSourceInfoA
	******************************************************************** */
	#define tDataSourceInfo tDataSourceInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tDataSourceInfoU, tDataSourceInfoA
	******************************************************************** */
	#define tDataSourceInfo tDataSourceInfoA
#endif

/* ********************************************************************
Description: 
A Unicode structure to contain information for a single snap with pre-information. 
Use this struct if your program runs in UNICODE mode. 

SeeAlso:     
tSnapInfoA, tSnapInfo

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tSnapInfo that automatically chooses the right type.
******************************************************************** */
typedef struct cSnapInfoU
{
	// constructor
	inline cSnapInfoU()
	{
		uAdapterInfoCount = 0;
		pAdapterInfo	  = NULL;
	};

	// the adapter info array
	tAdapterU* pAdapterInfo;
	
	// the amount of adapter infos
	UINT uAdapterInfoCount;
}tSnapInfoU;

/* ********************************************************************
Description: 
A ASCII structure to contain information for a single snap with pre-information. 
Use this struct if your program runs in ASCII mode. 

SeeAlso:     
tSnapInfoU, tSnapInfo

Remarks:     
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro tSnapInfo that automatically chooses the right type.
******************************************************************** */
typedef struct cSnapInfoA
{
	// constructor
	inline cSnapInfoA()
	{
		uAdapterInfoCount = 0;
		pAdapterInfo	  = NULL;
	};

	// the adapter info array
	tAdapterA* pAdapterInfo;

	// the amount of adapter infos
	UINT uAdapterInfoCount;
}tSnapInfoA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tSnapInfoU, tSnapInfoA
	******************************************************************** */
	#define tSnapInfo tSnapInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tSnapInfoU, tSnapInfoA
	******************************************************************** */
	#define tSnapInfo tSnapInfoA
#endif

/* ********************************************************************
Description: 
The result of s calibration attempt
******************************************************************** */
typedef struct
{
	// calibration result (SeeAlso: eReturnCodes) 
	int iResult;
	// calibration sigma
	double dSigma0;
}tCalibrationResult;

/* ********************************************************************
Description: 
The type of a calibration
******************************************************************** */
enum eCalibrationTypes
{
	/*     The currently active mode */
	calib_LastActive = -1,

	/*     The system is calibrated with a panel. */
	calib_Panel = 0,

	/*     The system is calibrated with a scale bar. 
		Is only allowed to be set for multi camera systems with 
		static geometry.*/
	calib_Scale,

	/*     The system is calibrated with one or more reference point fields and
        additional scales (optional). Unknown new targets can be included
        in the calibration too (optional). */
    calib_ReferenceAndObjects,
};
	   
/* ********************************************************************
Description: 
The parameter of a calibration
******************************************************************** */
typedef struct
{
	// calibration mode (SeeAlso: eCalibrationTypes) 
	int iCalibrationType;
}tCalibrationParam;

/* ********************************************************************
Description: 
The flags which IOR values are calibrated
******************************************************************** */
enum eCalibrationIORFlags
{
	// Flag to activate the focal distance calibration
	calib_AdjustCk = 0x00001,
	// Flag to activate the sensor center point calibration.
	calib_AdjustXH = 0x00002,
	calib_AdjustYH = 0x00004,
	// Flag to activate the a1 param calibration.
	calib_AdjustA1 = 0x00010,
	// Flag to activate the a2 param calibration.
	calib_AdjustA2 = 0x00020,
	// Flag to activate the a3 param calibration.
	calib_AdjustA3 = 0x00040,
	// Flag to activate the b1 param calibration.
	calib_AdjustB1 = 0x00100,
	// Flag to activate the b2 param calibration.
	calib_AdjustB2 = 0x00200,
	// Flag to activate the c1 param calibration.
	calib_AdjustC1 = 0x00400,
	// Flag to activate the c2 param calibration.
	calib_AdjustC2 = 0x00800
};

/* ********************************************************************
Description: 
The information of a calibration
******************************************************************** */
typedef struct
{
	// calibration mode (SeeAlso: eCalibrationTypes) 
	int iCalibrationType;
	// The calibrated camera values (SeeAlso: eCalibrationIORFlags)
	int iIORFlags;
	// Name of the active scale bar
	wchar_t cSelectedScale[128];
	// Name of the active panel
	wchar_t cSelectedPanel[128];
	// Name of the selected reference cross
	wchar_t cSelectedCross[128];
}tCalibrationInfoU;

/* ********************************************************************
Description: 
The parameter of a calibration
******************************************************************** */
typedef struct
{
	// calibration mode (SeeAlso: eCalibrationTypes) 
	int iCalibrationType;
	// The calibrated camera values (SeeAlso: eCalibrationIORFlags)
	int iIORFlags;
	// Name of the active scale bar
	char cSelectedScale[128];
	// Name of the active panel
	char cSelectedPanel[128];
	// Name of the selected reference cross
	char cSelectedCross[128];
}tCalibrationInfoA;

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tCalibrationInfoU, tCalibrationInfoA
	******************************************************************** */
	#define tCalibrationInfo tCalibrationInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: tCalibrationInfoU, tCalibrationInfoA
	******************************************************************** */
	#define tCalibrationInfo tCalibrationInfoA
#endif

/* ********************************************************************
Description: 
The referencing modes
******************************************************************** */
enum eReferencingMode
{
	// No referencing is turned on
	refmode_None    = 0,
	// Dynamic referencing 
	refmode_Dynamic = 1,
	// OneShot referencing
	refmode_OneShot = 2,
};

#pragma pack (pop)
}

// ***************************************************************************
#endif