/* ********************************************************************
Description: 
Include header for AICON_Receiver.dll. Include this into your source and the
linker automatically includes the necessary library.

Author:
Marcel Ellerbrok

Revision:
* 09.11.2007 - ME - First stable version
* 21.09.2010 - ME - Added transfer of whole point sets
 **********************************************************************/
#ifndef __AICON_RECEIVER_DLL__
#define __AICON_RECEIVER_DLL__

#if _MSC_VER > 1000
	#pragma once
#endif

// ---------------------------------------------------------------------------
#ifdef AICON_RECEIVER_DLL_EXPORTS
	#define  RECEIVER_API __declspec(dllexport)
#else
	#define  RECEIVER_API __declspec(dllimport)

	#ifdef WIN64
		#pragma message( "AICON Libary Manager will automatically link with AICON_Receiver64.lib" )
		#pragma comment(lib, "AICON_Receiver64.lib")
	#else
		#pragma message( "AICON Libary Manager will automatically link with AICON_Receiver.lib" )
		#pragma comment(lib, "AICON_Receiver.lib")
	#endif
#endif

// include the data types
#include "AICON_Receiver_Data.h"

// ---------------------------------------------------------------------------
extern "C"
{

// Internally we use a structure packing of 8 bit.
#pragma pack( push, 8)

/* ********************************************************************
Description: 
Call this function once to initialize the module. Use this function if 
your program runs in Unicode mode. 

Parameters:
pAppName  - You have to pass in the name of your application.
pLanguage - You may pass in the name of the desired language
                     or a NULL value. For there is no support of special 
					 languages this value is reserved for future use. 
Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

SeeAlso:     
gReceiver_InitA, gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_InitU(wchar_t *pAppName, wchar_t *pLanguage = NULL);

/* ********************************************************************
Description: 
Call this function once to initialize the module. Use this function if 
your program runs in ASCII mode. 

Parameters:
pAppName  - You have to pass in the name of your application.
pLanguage - You may pass in the name of the desired language
                  or a NULL value. For there is no support of special 
				  languages this value is reserved for future use. 
Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

SeeAlso:     
gReceiver_InitA, gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_InitA(char *pAppName, char *pLanguage = NULL);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_InitU, gReceiver_InitA
	******************************************************************** */
	#define gReceiver_Init gReceiver_InitU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_InitU, gReceiver_InitA
	******************************************************************** */
	#define gReceiver_Init gReceiver_InitA
#endif

/* ********************************************************************
Description: 
Call this function to initialize the communication service of this
receiver.

Parameters:
uInitialMeasureMode  - On connection of an AICON measurement system 
							it will be set to this measure mode. All 
							measure modes start at an id of 0x100. After 
							the connection to a measurement device you can
							query the available measure modes by calling
							gReceiver_GetMeasureModeCount and
							gReceiver_GetMeasureModeInfo

pNetworkLocation - Network mask where we search for data sources. 
						   This string may be "127.0.0.255" for local sources, 
						   a specific IP-Mask like "172.16.255.255" or my 
						   be blank for the entire local area network

						   Returns:
* rcSuccess              - All done.
* rcNotInitialized       - You never called gReceiver_Init
* rcServerAlreadyRunning - The communication server is already running

SeeAlso:     
gReceiver_Init, gReceiver_GetMeasureModeCount, gReceiver_GetMeasureModeInfo
******************************************************************** */
RECEIVER_API UINT gReceiver_StartServerU(UINT uInitialMeasureMode = 0x100, wchar_t *pNetworkLocation = NULL);

/* ********************************************************************
Description: 
Call this function to initialize the communication service of this
receiver.

Parameters:
uInitialMeasureMode  - On connection of an AICON measurement system 
							it will be set to this measure mode. All 
							measure modes start at an id of 0x100. After 
							the connection to a measurement device you can
							query the available measure modes by calling
							gReceiver_GetMeasureModeCount and
							gReceiver_GetMeasureModeInfo

pNetworkLocation -  Network mask where we search for data sources. 
						  This string may be "127.0.0.255" for local sources, 
						  a specific IP-Mask like "172.16.255.255" or my 
						  be blank for the entire local area network

Returns:
* rcSuccess              - All done.
* rcNotInitialized       - You never called gReceiver_Init
* rcServerAlreadyRunning - The communication server is already running

SeeAlso:     
gReceiver_Init, gReceiver_GetMeasureModeCount, gReceiver_GetMeasureModeInfo
******************************************************************** */
RECEIVER_API UINT gReceiver_StartServerA(UINT uInitialMeasureMode = 0x100, char *pNetworkLocation = NULL);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_StartServerU, gReceiver_StartServerA
	******************************************************************** */
	#define gReceiver_StartServer gReceiver_StartServerU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_StartServerU, gReceiver_StartServerA
	******************************************************************** */
	#define gReceiver_StartServer gReceiver_StartServerA
#endif

/* ********************************************************************
Description: 
Call this function to terminate the communication service of this
receiver.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcServerNotRunning - The communication server was not started

SeeAlso:     
gReceiver_Init, gReceiver_StartServer
******************************************************************** */
RECEIVER_API UINT gReceiver_StopServer(void);

/* ********************************************************************
Description: 
Final cleanup function to release all used resources.

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init

SeeAlso:     
gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_Release(void);

/* ********************************************************************
Description: 
This function returns whether or not an AICON device (like MoveInspect) is
connected to the receiver.

Returns:
* rcSuccess			- The communication to an AICON device was established
* rcNotInitialized  - You never called gReceiver_Init
* rcNotConnected    - No device is connected
******************************************************************** */
RECEIVER_API UINT gReceiver_IsConnected();

/* ********************************************************************
Description: 
Call this function to prevent the backlogging of received data. A new 
received data-set replaces any old data set in the receive queue. Except
of triggered data. They remain untouched.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init

SeeAlso:     
gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_PreventDataBacklog(bool bPrevent = true);

/* ********************************************************************
Description: 
Call this function to remove all data from the input buffer. This will
remove all data regardless of their trigger state.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init

SeeAlso:     
gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_CleanResultBuffer();

/* ********************************************************************
Description: 
Call this function to determine the number of available data sources for
the connection. You may use this value to get the data source informations 
via gReceiver_GetDataSourceInfoVec.

Returns:
* 0   - No AICON data sources are available. 
* > 0 - The number of available data sources.

SeeAlso:     
gReceiver_GetDataSourceInfo
******************************************************************** */
RECEIVER_API size_t gReceiver_GetDataSourceCount();

/* ********************************************************************
Description: 
Call this function to retrieve more information about all available 
data sources. Use this function if your program runs in Unicode mode. 

Parameters:
pInfoVec - Pointer to an array of tDataSourceU structs.

iNumberOfElements - Pass in the size of the array

Remarks:
You have to call gReceiver_GetDataSourceCount first and than allocate an array of
tDataSourceInfoU large enough to contain all data from all templates.

To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetDataSourceInfoVec that automatically chooses 
the right type.

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init

SeeAlso:     
gReceiver_GetDataSourceInfoVecA, gReceiver_GetDataSourceInfoVec, gReceiver_GetDataSourceCount
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataSourceInfoVecU(tDataSourceInfoU *pInfoVec, size_t iNumberOfElements);

/* ********************************************************************
Description: 
Call this function to retrieve more information about all available 
data sources. Use this function if your program runs in ASCII mode. 

Parameters:
pInfoVec - Pointer to an array of tDataSourceU structs.

iNumberOfElements - Pass in the size of the array

Remarks:
You have to call gReceiver_GetDataSourceCount first and than allocate an array of
tDataSourceInfoA large enough to contain all data from all templates.

To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetDataSourceInfoVec that automatically chooses 
the right type.

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init

SeeAlso:     
gReceiver_GetDataSourceInfoVecU, gReceiver_GetDataSourceInfoVec, gReceiver_GetDataSourceCount
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataSourceInfoVecA(tDataSourceInfoA *pInfoVec, size_t iNumberOfElements);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetDataSourceInfoVecU, gReceiver_GetDataSourceInfoVecA
	******************************************************************** */
	#define gReceiver_GetDataSourceInfoVec gReceiver_GetDataSourceInfoVecU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetDataSourceInfoVecU, gReceiver_GetDataSourceInfoVecA
	******************************************************************** */
	#define gReceiver_GetDataSourceInfoVec gReceiver_GetDataSourceInfoVecA
#endif

/* ********************************************************************
Description: 
Call this function to start a connection.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init

SeeAlso:     
gReceiver_Init, gReceiver_StartServer
******************************************************************** */
RECEIVER_API UINT gReceiver_StartConnection(GUID cSourceID = GUID_ZERO);

/* ********************************************************************
Description: 
Call this function to start a connection to a given ip address or host name

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init

SeeAlso:     
gReceiver_Init, gReceiver_StartServer
******************************************************************** */
RECEIVER_API UINT gReceiver_StartConnectionByIPU(wchar_t *pIP, int iPort);

/* ********************************************************************
Description: 
Call this function to start a connection to a given ip address or host name

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init

SeeAlso:     
gReceiver_Init, gReceiver_StartServer
******************************************************************** */
RECEIVER_API UINT gReceiver_StartConnectionByIPA(char *pIP, int iPort);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_StartConnectionByIPU, gReceiver_StartConnectionByIPA
	******************************************************************** */
	#define gReceiver_StartConnectionByIP gReceiver_StartConnectionByIPU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_StartConnectionByIPU, gReceiver_StartConnectionByIPA
	******************************************************************** */
	#define gReceiver_StartConnectionByIP gReceiver_StartConnectionByIPA
#endif

/* ********************************************************************
Description: 
Call this function to terminate the current connection.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device

SeeAlso:     
gReceiver_Init, gReceiver_StartServer
******************************************************************** */
RECEIVER_API UINT gReceiver_StopConnection(void);

/* ********************************************************************
Description: 
Call this function to determine the number of available measure modes for
the connected AICON device. You may use this value to get the measure mode
informations via gReceiver_GetMeasureModeInfo.

Returns:
* 0   - No measure modes are available. This indicates that no device is connected
* > 0 - The number of available measure modes.

SeeAlso:     
gReceiver_GetMeasureModeInfo
******************************************************************** */
RECEIVER_API size_t gReceiver_GetMeasureModeCount();

/* ********************************************************************
Description: 
Call this function to determine the number of available calibration modes for
the connected AICON device. You may use this value to get the calibration mode
informations via gReceiver_GetMeasureModeInfo.

Returns:
* 0   - No measure modes are available. This indicates that no device is connected
* > 0 - The number of available measure modes.

SeeAlso:     
gReceiver_GetMeasureModeInfo
******************************************************************** */
RECEIVER_API size_t gReceiver_GetCalibrationModeCount();

/* ********************************************************************
Description: 
Call this function once to retrieve more information about an available 
measure mode. Use this function if your program runs in Unicode mode. 

Parameters:
uMode - You have to pass in the identification of the measure mode.

             Measure modes identifications are starting at 0x100. You may
			 use gReceiver_GetMeasureModeCount to determine the number of
			 available measure modes.

			 Calibration modes identifications are starting at 0x200. You may
			 use gReceiver_GetCalibrationModeCount to determine the number of
			 available calibration modes.

cInfo -  Reference to a unicode measure mode information 
							structure.

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init
* rcNotConnected   - You are not connected to an AICON device

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetMeasureModeInfo that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetMeasureModeInfoA, gReceiver_GetMeasureModeInfo, gReceiver_GetMeasureModeCount
******************************************************************** */
RECEIVER_API UINT gReceiver_GetMeasureModeInfoU(UINT uMode, tMeasureModeInfoU &cInfo);

/* ********************************************************************
Description: 
Call this function once to retrieve more information about an available 
measure mode. Use this function if your program runs in ASCII mode. 

Parameters:
uMode - You have to pass in the identification of the measure mode.

				Measure modes identifications are starting at 0x100. You may
				use gReceiver_GetMeasureModeCount to determine the number of
				available measure modes.

				Calibration modes identifications are starting at 0x200. You may
				use gReceiver_GetCalibrationModeCount to determine the number of
				available calibration modes.

cInfo -  Reference to a ASCII measure mode information 
							structure.

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init
* rcNotConnected   - You are not connected to an AICON device

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetMeasureModeInfo that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetMeasureModeInfoU, gReceiver_GetMeasureModeInfo, gReceiver_GetMeasureModeCount
******************************************************************** */
RECEIVER_API UINT gReceiver_GetMeasureModeInfoA(UINT uMode, tMeasureModeInfoA &cInfo);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetMeasureModeInfoU, gReceiver_GetMeasureModeInfoA
	******************************************************************** */
	#define gReceiver_GetMeasureModeInfo gReceiver_GetMeasureModeInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetMeasureModeInfoU, gReceiver_GetMeasureModeInfoA
	******************************************************************** */
	#define gReceiver_GetMeasureModeInfo gReceiver_GetMeasureModeInfoA
#endif

/* ********************************************************************
Description: 
Call this function to determine the current measure mode of the connected 
AICON device.

Returns:
* 0   - No measure modes. This indicates that no device is connected
* > 0 - The identification of the current measure modes.
******************************************************************** */
RECEIVER_API UINT gReceiver_GetCurrentMeasureMode();

/* ********************************************************************
Description: 
Use this function to change the measure mode of the connected AICON device.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
* rcWrongMeasureMode - The provided measure mode was not valid
******************************************************************** */
RECEIVER_API UINT gReceiver_ChangeMeasureMode(UINT iMode);

/* ********************************************************************
Description: 
Call this function to determine the number of available references for
the connected AICON device. You may use this value to get the reference
information via gReceiver_GetReferenceName.

Returns:
* 0   - No measure modes are available. This indicates that no device is connected
* > 0 - The number of available measure modes.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_GetMeasureModeInfo
******************************************************************** */
RECEIVER_API UINT gReceiver_GetReferenceNameCount();

/* ********************************************************************
Description: 
Call this function to get the name of the reference with the given index.

Parameters:
uNameIdx    - Index of the reference.
pRefName - [out]Pointer to receiving buffer
iBufSize  - Size of the receiving buffer		

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_GetReferenceNameA, gReceiver_GetReferenceName
******************************************************************** */
RECEIVER_API UINT gReceiver_GetReferenceNameU(UINT uNameIdx, wchar_t *pRefName, int iBufSize);

/* ********************************************************************
Description: 
Call this function to get the name of the reference with the given index.

Parameters:
uNameIdx    - Index of the reference.
pRefName - [out]Pointer to receiving buffer
iBufSize  - Size of the receiving buffer		

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_GetReferenceNameU, gReceiver_GetReferenceName
******************************************************************** */
RECEIVER_API UINT gReceiver_GetReferenceNameA(UINT iNameIdx, char *pRefName, int iBufSize);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.00.xx or higher

	SeeAlso: gReceiver_GetReferenceNameU, gReceiver_GetReferenceNameA
	******************************************************************** */
	#define gReceiver_GetReferenceName gReceiver_GetReferenceNameU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.00.xx or higher

	SeeAlso: gReceiver_GetReferenceNameU, gReceiver_GetReferenceNameA
	******************************************************************** */
	#define gReceiver_GetReferenceName gReceiver_GetReferenceNameA
#endif

/* ********************************************************************
Description: 
This is deprecated. Use gReceiver_SetReferenceModeU instead!
******************************************************************** */
RECEIVER_API UINT gReceiver_SetActiveReferenceU(wchar_t *pRefName);

/* ********************************************************************
Description: 
This is deprecated. Use gReceiver_SetReferenceModeA instead!
******************************************************************** */
RECEIVER_API UINT gReceiver_SetActiveReferenceA(char *pRefName);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This is deprecated. Use gReceiver_SetReferenceMode instead!
	******************************************************************** */
	#define gReceiver_SetActiveReference gReceiver_SetActiveReferenceU
#else				
	/* ********************************************************************
	Description: 
	This is deprecated. Use gReceiver_SetReferenceMode instead!
	******************************************************************** */
	#define gReceiver_SetActiveReference gReceiver_SetActiveReferenceA
#endif

/* ********************************************************************
Description: 
This is deprecated. Use gReceiver_GetReferenceModeU instead!
******************************************************************** */
RECEIVER_API UINT gReceiver_GetActiveReferenceU(wchar_t *pRefName, int iBufSize);

/* ********************************************************************
Description: 
This is deprecated. Use gReceiver_GetReferenceModeA instead!
******************************************************************** */
RECEIVER_API UINT gReceiver_GetActiveReferenceA(char *pRefName, int iBufSize);

#ifdef _UNICODE		
	/* ********************************************************************
	This is deprecated. Use gReceiver_GetReferenceMode instead!
	******************************************************************** */
	#define gReceiver_GetActiveReference gReceiver_GetActiveReferenceU
#else				
	/* ********************************************************************
	This is deprecated. Use gReceiver_GetReferenceMode instead!
	******************************************************************** */
	#define gReceiver_GetActiveReference gReceiver_GetActiveReferenceA
#endif

/* ********************************************************************
Description: 
Call this function to create a reference with the given name.

Parameters:
pRefName - [in]Name of the new reference
pRefPoints - [in]Array of all coordinates
iBufSize - [in]Number of points in pRefPoints array
bOneShot - [in]Activate the MoveInspect OneShot-Referencing 

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_CreateReference that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.01.xx or higher

SeeAlso:     
gReceiver_CreateReferenceA, gReceiver_CreateReference
******************************************************************** */
RECEIVER_API UINT gReceiver_CreateReferenceU(wchar_t *pRefName, tPointU *pRefPoints, int iBufSize, bool bOneShotRef = false);

/* ********************************************************************
Description: 
Call this function to create a reference with the given name.

Parameters:
pRefName - [in]Name of the new reference
pRefPoints - [in]Array of all coordinates
iBufSize - [in]Number of points in pRefPoints array
bOneShot - [in]Activate the MoveInspect OneShot-Referencing 

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_CreateReference that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.01.xx or higher

SeeAlso:     
gReceiver_CreateReferenceU, gReceiver_CreateReference
******************************************************************** */
RECEIVER_API UINT gReceiver_CreateReferenceA(char *pRefName, tPointA *pRefPoints, int iBufSize, bool bOneShotRef = false);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.01.xx or higher

	SeeAlso: gReceiver_CreateReferenceU, gReceiver_CreateReferenceA
	******************************************************************** */
	#define gReceiver_CreateReference gReceiver_CreateReferenceU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.01.xx or higher

	SeeAlso: gReceiver_CreateReferenceU, gReceiver_CreateReferenceA
	******************************************************************** */
	#define gReceiver_CreateReference gReceiver_CreateReferenceA
#endif

/* ********************************************************************
Description: 
Save the current epoch as one shot reference.

Returns:
* rcSuccess        - The one shot reference was created
* rcNotInitialized - You never called gReceiver_Init
* rcNotAvailable   - The connected data source does not support this feature
* rcWrongState     - The one shot reference mode is not active
* rcFailed		   - Failed to create the one shot reference

******************************************************************** */
RECEIVER_API UINT gReceiver_CreateOneShotReference();

/* ********************************************************************
Description: 
This function indicates that there is any data to collect via 
gReceiver_GetData.

Returns:
* rcSuccess        - There is data available
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no data available at the moment

SeeAlso:     
gReceiver_GetData
******************************************************************** */
RECEIVER_API UINT gReceiver_HasDataReceived();

/* ********************************************************************
Description: 
Instead of polling for data it is possible to register an event callback
function to get informed about events.

Parameters:
pEventCallback - Pointer to a callback function to set the callback, or NULL 
                 so clear the callback.

pUserData - A pointer to some data that will be returned to the event 
            callback.

Returns:
* rcSuccess        - Setting the callback succeeded
* rcFailed         - Setting the callback failed
* rcNotInitialized - You never called gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_SetEventCallback(tReceiver_EventCallbackPtr pEventCallback, void* pUserData = NULL);

/* ********************************************************************
Description: 
Use this function to start and stop receiving camera information.

Parameters:
bGetCameraInfo - This will toggle the retrieval

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_RetrieveCameraInformation(bool bGetCameraInfo);

/* ********************************************************************
Description: 
Use this function to get the raw images of the next snap.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_RetrieveImagesOfNextSnap();

/* ********************************************************************
Description: 
If there is data available, this function return the amount of points
that the receiving buffer has to handle.

Returns:
* 0   - No points. This indicates that you don't need a point buffer
* > 0 - The amount of points that have to fit into the point buffer
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataPointCnt();

/* ********************************************************************
Description: 
If there is data available, this function return the amount of cameras
that the receiving buffer has to handle.

Returns:
* 0   - No cameras. This indicates that you don't need a camera buffer
* > 0 - The amount of cameras that have to fit into the camera buffer
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataCameraCnt();

/* ********************************************************************
Description: 
If there is 6DoF information available, this function return the amount 
of 6DoF objects that the receiving buffer has to handle.

Returns:
* 0   - No 6DoF. This indicates that you don't need a camera buffer
* > 0 - The amount of 6DoF objects that have to fit into the buffer
******************************************************************** */
RECEIVER_API UINT gReceiver_GetData6DoFCnt();

/* ********************************************************************
Description: 
If there are images available, this function return the amount of 
images that the receiving buffer has to handle.

Returns:
* 0   - No images. This indicates that you don't need a images buffer
* > 0 - The amount of images that have to fit into the images buffer
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataImageCnt();

/* ********************************************************************
Description: 
If there are sensors available, this function return the amount of 
sensors that the receiving buffer has to handle.

Returns:
* 0   - No sensors. This indicates that you don't need a sensor buffer
* > 0 - The amount of sensors that have to fit into the sensor buffer
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataSensorCnt();

/* ********************************************************************
Description: 
Get the sizes of the image pixel and color table buffers.

Parameters:
iImageIndex      - The index of the image to retrieve the data of
iPixelBufferSize - This will retrieve the size of the pixel buffer
iColorTableSize  - This will retrieve the size of the color table buffer

Returns:
* rcSuccess        - The data is valid
* rcFailed         - Failed to retrieve the data
* rcNotInitialized - You never called gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_GetImageBufferSize(int iImageIndex, unsigned int& iPixelBufferSize, unsigned int& iColorTableSize);

/* ********************************************************************
Description: 
Call this function to retrieve the received data. Use this function if 
your program runs in Unicode mode. 

Parameters:
cPoint     - A reference to an unicode data structure.

Returns:
* rcSuccess        - cPoint contains valid data.
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no data available at the moment

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetData that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetDataA, gReceiver_GetData
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataU(cDataU &cPoint);

/* ********************************************************************
Description: 
Call this function to retrieve the received data. Use this function if 
your program runs in ASCII mode. 

Parameters:
cPoint     - A reference to an ASCII data structure.

Returns:
* rcSuccess        - cPoint contains valid data.
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no data available at the moment

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetData that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetDataU, gReceiver_GetData
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataA(cDataA &cPoint);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetDataU, gReceiver_GetDataA
	******************************************************************** */
	#define gReceiver_GetData gReceiver_GetDataU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetDataU, gReceiver_GetDataA
	******************************************************************** */
	#define gReceiver_GetData gReceiver_GetDataA
#endif

/* ********************************************************************
Description: 
Call this function to retrieve the name of the connected AICON device. 
Use this function if your program runs in UNICODE mode. 

Parameters:
pDataSourceName - Pointer to a wchar_t array to receive the name.
iBufSize        - Size of the pDataSourceName buffer.

Returns:
* rcSuccess        - cPoint contains valid data.
* rcNotInitialized - You never called gReceiver_Init

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetDataSourceName that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetDataSourceNameU, gReceiver_GetDataSourceName
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataSourceNameU(wchar_t *pDataSourceName, size_t iBufSize);

/* ********************************************************************
Description: 
Call this function to retrieve the name of the connected AICON device. 
Use this function if your program runs in ASCII mode. 

Parameters:
pDataSourceName - Pointer to a char array to receive the name.
iBufSize        - Size of the pDataSourceName buffer.

Returns:
* rcSuccess        - cPoint contains valid data.
* rcNotInitialized - You never called gReceiver_Init

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetDataSourceName that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetDataSourceNameU, gReceiver_GetDataSourceName
******************************************************************** */
RECEIVER_API UINT gReceiver_GetDataSourceNameA(char *pDataSourceName, size_t iBufSize);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetDataSourceNameU, gReceiver_GetDataSourceNameA
	******************************************************************** */
	#define gReceiver_GetDataSourceName gReceiver_GetDataSourceNameU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetDataSourceNameU, gReceiver_GetDataSourceNameA
	******************************************************************** */
	#define gReceiver_GetDataSourceName gReceiver_GetDataSourceNameA
#endif

/* ********************************************************************
Description: 
Use this function to trigger a single measurement of the connected AICON 
device.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
* rcNotAvailable     - Not possible due collision with other trigger signal
******************************************************************** */
RECEIVER_API UINT gReceiver_SendDoSingleMeasurement(void);

/* ********************************************************************
Description: 
Use this function to trigger a single measurement of the connected AICON 
device.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
* rcNotAvailable     - Not possible due collision with other trigger signal
******************************************************************** */
RECEIVER_API UINT gReceiver_SendDoSingleMeasurementWithInfoU( tSnapInfoU* pSnapInfo );

/* ********************************************************************
Description: 
Use this function to trigger a single measurement of the connected AICON 
device.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
******************************************************************** */
RECEIVER_API UINT gReceiver_SendDoSingleMeasurementWithInfoA( tSnapInfoA* pSnapInfo );

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_SendDoSingleMeasurementWithInfoU, gReceiver_SendDoSingleMeasurementWithInfoA
	******************************************************************** */
	#define gReceiver_SendDoSingleMeasurementWithInfo gReceiver_SendDoSingleMeasurementWithInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_SendDoSingleMeasurementWithInfoU, gReceiver_SendDoSingleMeasurementWithInfoA
	******************************************************************** */
	#define gReceiver_SendDoSingleMeasurementWithInfo gReceiver_SendDoSingleMeasurementWithInfoA
#endif

/* ********************************************************************
Description: 
Use this function to start continuous measurement of the connected AICON 
device.

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
******************************************************************** */
RECEIVER_API UINT gReceiver_SendStartLiveMeasurement(void);

/* ********************************************************************
Description: 
Use this function to stop continuous measurement of the connected AICON 
device.

Parameters:
bCleanResultBuffer - After stopping the live measurement there may be 
 a backlog of results in the internal buffer. Setting this option to true 
 will wipe all not transferred data from the buffer.


Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
******************************************************************** */
RECEIVER_API UINT gReceiver_SendStopLiveMeasurement(bool bCleanResultBuffer = false);

/* ********************************************************************
Description: 
This function indicates whether continuous measurement is running or not.

Returns:
* rcSuccess        - Continuous measurement running
* rcFailed		   - Continuous measurement NOT running
* rcNotInitialized - You never called gReceiver_Init

******************************************************************** */
RECEIVER_API UINT gReceiver_IsLiveMeasurement();

/* ********************************************************************
Description: 
Gets the version information of this dll. Use this function if your 
program runs in ASCII mode.  

Parameters:
pVersionInfo - The buffer to receive the version info
iBufSize     - The size of the buffer

Remarks
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetVersionInfo that automatically chooses the 
right type.

SeeAlso:
gReceiver_GetVersionInfoU, gReceiver_GetVersionInfo

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_GetVersionInfoA(char *pVersionInfo, int iBufSize);

/* ********************************************************************
Description: 
Gets the version information of this dll. Use this function if your 
program runs in Unicode mode.  

Parameters:
pVersionInfo - The buffer to receive the version info
iBufSize     - The size of the buffer

Remarks
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetVersionInfo that automatically chooses the 
right type.

SeeAlso:
gReceiver_GetVersionInfoA, gReceiver_GetVersionInfo

Returns:
* rcSuccess        - All done.
* rcNotInitialized - You never called gReceiver_Init
******************************************************************** */
RECEIVER_API UINT gReceiver_GetVersionInfoU(wchar_t *pVersionInfo, int iBufSize);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetVersionInfoU, gReceiver_GetVersionInfoA
	******************************************************************** */	
	#define gReceiver_GetVersionInfo gReceiver_GetVersionInfoU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetVersionInfoU, gReceiver_GetVersionInfoA
	******************************************************************** */
	#define gReceiver_GetVersionInfo gReceiver_GetVersionInfoA
#endif

/* ********************************************************************
Description: 
Call this function to retrieve the current location where the receiver dll
is searching for data sources. Use this function if your program runs in UNICODE mode. 

Parameters:
pNetworkLocation - Pointer to a wchar_t array to receive the search mask.
							This may be "127.0.0.255" for local sources, 
							a specific IP-Mask like "172.16.255.255" or my 
							be blank for the entire local area network.

iBufSize  - Size of the pLocation buffer.

Returns:
* rcSuccess        - pNetworkLocation contains valid data.
* rcFailed         - The buffer size may be to small
* rcNotInitialized - You never called gReceiver_Init

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetSourceLocation that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetSourceLocationA, gReceiver_GetSourceLocation
******************************************************************** */
RECEIVER_API UINT gReceiver_GetSourceLocationU(wchar_t *pNetworkLocation, size_t iBufSize);

/* ********************************************************************
Description: 
Call this function to retrieve the current location where the receiver dll
is searching for data sources. Use this function if your program runs in ASCII mode. 

Parameters:
pNetworkLocation - Pointer to a wchar_t array to receive the search mask.
                         This may be "127.0.0.255" for local sources, 
                         a specific IP-Mask like "172.16.255.255" or my 
                         be blank for the entire local area network.

iBufSize  - Size of the pLocation buffer.

Returns:
* rcSuccess        - pNetworkLocation contains valid data.
* rcFailed         - The buffer size may be to small
* rcNotInitialized - You never called gReceiver_Init

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_GetSourceLocation that automatically chooses 
the right type.

SeeAlso:     
gReceiver_GetSourceLocationU, gReceiver_GetSourceLocation
******************************************************************** */
RECEIVER_API UINT gReceiver_GetSourceLocationA(char *pNetworkLocation, size_t iBufSize);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetSourceLocationU, gReceiver_GetSourceLocationA
	******************************************************************** */
	#define gReceiver_GetSourceLocation gReceiver_GetSourceLocationU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetSourceLocationU, gReceiver_GetSourceLocationA
	******************************************************************** */
	#define gReceiver_GetSourceLocation gReceiver_GetSourceLocationA
#endif

/* ********************************************************************
Description: 
Call this function to set the location where the receiver dll is searching 
for data sources. Use this function if your program runs in UNICODE mode. 

Parameters:
pNetworkLocation - Pointer to a wchar_t array that contains the search 
                            location network mask. This may be "127.0.0.255" for 
							local sources, a specific IP-Mask like "172.16.255.255" 
 						    or may be blank for the entire local area network.

Returns:
* rcSuccess        - The location was successfully set
* rcNotInitialized - You never called gReceiver_Init

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_SetSourceLocation that automatically chooses 
the right type.

SeeAlso:     
gReceiver_SetSourceLocationA, gReceiver_SetSourceLocation
******************************************************************** */
RECEIVER_API UINT gReceiver_SetSourceLocationU(wchar_t *pNetworkLocation);

/* ********************************************************************
Description: 
Call this function to set the location where the receiver dll is searching 
for data sources. Use this function if your program runs in ASCII mode. 

Parameters:
pNetworkLocation - Pointer to a wchar_t array that contains the search 
                         location network mask. This may be "127.0.0.255" for 
                         local sources, a specific IP-Mask like "172.16.255.255" 
                         or may be blank for the entire local area network.

Returns:
* rcSuccess        - The location was successfully set
* rcNotInitialized - You never called gReceiver_Init

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_SetSourceLocation that automatically chooses 
the right type.

SeeAlso:     
gReceiver_SetSourceLocationU, gReceiver_SetSourceLocation
******************************************************************** */
RECEIVER_API UINT gReceiver_SetSourceLocationA(char *pNetworkLocation);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_SetSourceLocationU, gReceiver_SetSourceLocationA
	******************************************************************** */
	#define gReceiver_SetSourceLocation gReceiver_SetSourceLocationU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_SetSourceLocationU, gReceiver_SetSourceLocationA
	******************************************************************** */
	#define gReceiver_SetSourceLocation gReceiver_SetSourceLocationA
#endif

/* ********************************************************************
Description: 
Use this function to start calculation of the calibration. This presumes
you have entered a calibration measure mode and have made some calibration
measurements. 

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
* rcWrongMeasureMode - You are not in calibration mode
******************************************************************** */
RECEIVER_API UINT gReceiver_SendStartCalibCalculation(void);

/* ********************************************************************
Description: 
This function indicates that there is any calibration result to collect via 
gReceiver_GetCalibResult.

Returns:
* rcSuccess        - There is a result available
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no result available at the moment

SeeAlso:     
gReceiver_GetCalibResult
******************************************************************** */
RECEIVER_API UINT gReceiver_HasCalibResultReceived(void);

/* ********************************************************************
Description: 
Call this function to retrieve the calibration result data.

Parameters:
pcCalibData - A pointer to the receiving data structure.

Returns:
* rcSuccess        - pcCalibData contains valid data.
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no data available at the moment

SeeAlso:     
gReceiver_HasCalibResultReceived
******************************************************************** */
RECEIVER_API UINT gReceiver_GetCalibResult(tCalibrationResult* pcCalibData);

/* ********************************************************************
Description: 
Use this function to check mode type of a measure mode.

Returns:
* true - Measure mode is of the requested type.
* false - Measure mode is not the requested type
******************************************************************** */
RECEIVER_API bool gReceiver_IsModeOfType(UINT iMode, int iModeType);

/* ********************************************************************
Description: 
Use this function to check for the existence of a special mode type

Returns:
* true - A measure mode is of the requested type is present.
* false - No measure mode of this type is available
******************************************************************** */
RECEIVER_API bool gReceiver_HasModeOfType(int iModeType);

/* ********************************************************************
Description: 
Use this function to start a calibration.

Parameters:
iMode        - The calibration mode.
pcCalibParam - Calibration parameter object. Do NOT use 'calib_LastActive' as calibration type. 

Returns:
* rcSuccess          - All done.
* rcNotInitialized   - You never called gReceiver_Init
* rcNotConnected     - You are not connected to an AICON device
* rcFailed           - A transmission error occurred
* rcWrongMeasureMode - The provided mode was not valid
******************************************************************** */
RECEIVER_API UINT gReceiver_StartCalibrationMode(UINT iMode, tCalibrationParam* pcCalibParam);

/* ********************************************************************
Description: 
Call this function to retrieve the calibration settings.

Parameters:
pcCalibInfo - A pointer to the receiving data structure. SeeAlso: tCalibrationInfoU
iType       - The calibration type. Currently only 'calib_LastActive' is available. (SeeAlso: eCalibrationTypes) 

Returns:
* rcSuccess        - pcCalibInfo contains valid data.
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no data available at the moment

SeeAlso:     
gReceiver_GetCalibInformationA
******************************************************************** */
RECEIVER_API UINT gReceiver_GetCalibInformationU(tCalibrationInfoU* pcCalibInfo, int iType = calib_LastActive);

/* ********************************************************************
Description: 
Call this function to retrieve the calibration settings.

Parameters:
pcCalibInfo - A pointer to the receiving data structure. SeeAlso: tCalibrationInfoU
iType       - The calibration type. Currently only 'calib_LastActive' is available. (SeeAlso: eCalibrationTypes) 

Returns:
* rcSuccess        - pcCalibInfo contains valid data.
* rcNotInitialized - You never called gReceiver_Init
* rcFailed		   - There is no data available at the moment

SeeAlso:     
gReceiver_GetCalibInformationA
******************************************************************** */
RECEIVER_API UINT gReceiver_GetCalibInformationA(tCalibrationInfoA* pcCalibInfo, int iType = calib_LastActive);

#ifdef _UNICODE
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetCalibInformationU, gReceiver_GetCalibInformationA
	******************************************************************** */
	#define gReceiver_GetCalibInformation gReceiver_GetCalibInformationU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	SeeAlso: gReceiver_GetCalibInformationU, gReceiver_GetCalibInformationA
	******************************************************************** */
	#define gReceiver_GetCalibInformation gReceiver_GetCalibInformationA
#endif

/* ********************************************************************
Description: 
Call this function to change the current referencing mode. If a reference name 
is provided, this reference will be selected. If no reference name is provided,
the last used reference will be used. In case of refmode_None, the parameter 
pRefName will be ignored.

Parameters:
iMode - [in]The referencing mode. See: eReferencingMode
pRefName - [in]Pointer to reference name. This is optional.

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_SetReferenceMode that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_SetReferenceModeA, gReceiver_SetReferenceMode
******************************************************************** */
RECEIVER_API UINT gReceiver_SetReferenceModeU(int iMode, wchar_t *pRefName = NULL);

/* ********************************************************************
Description: 
Call this function to change the current referencing mode. If a reference name 
is provided, this reference will be selected. If no reference name is provided,
the last used reference will be used. In case of refmode_None, the parameter 
pRefName will be ignored.

Parameters:
iMode - [in]The referencing mode. See: eReferencingMode
pRefName - [in]Pointer to reference name. This is optional.

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_SetReferenceModeU, gReceiver_SetReferenceMode
******************************************************************** */
RECEIVER_API UINT gReceiver_SetReferenceModeA(int iMode, char *pRefName = NULL);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.00.xx or higher

	SeeAlso: gReceiver_SetReferenceModeU, gReceiver_SetReferenceModeA
	******************************************************************** */
	#define gReceiver_SetReferenceMode gReceiver_SetReferenceModeU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.00.xx or higher

	SeeAlso: gReceiver_SetReferenceModeU, gReceiver_SetReferenceModeA
	******************************************************************** */
	#define gReceiver_SetReferenceMode gReceiver_SetReferenceModeA
#endif

/* ********************************************************************
Description: 
Call this function to get the current referencing mode and the currently 
selected reference. Even if the referencing is turned off, the name of the 
last used reference is returned. 

Parameters:
iMode    - [out]The referencing mode. See: eReferencingMode 
pRefName - [out]Pointer to receiving buffer
iBufSize - [in]Size of the receiving buffer		

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_GetReferenceModeA, gReceiver_GetReferenceMode
******************************************************************** */
RECEIVER_API UINT gReceiver_GetReferenceModeU(int* iMode, wchar_t* pRefName = NULL, int iBufSize = 0);

/* ********************************************************************
Description: 
Call this function to get the current referencing mode and the currently 
selected reference. Even if the referencing is turned off, the name of the 
last used reference is returned. 

Parameters:
iMode    - [out]The referencing mode. See: eReferencingMode 
pRefName - [out]Pointer to receiving buffer
iBufSize - [int]Size of the receiving buffer		

Returns:
* rcSuccess - All done.

Remarks:
To ensure your program to be compilable with both Unicode and ASCII you 
should use the macro gReceiver_Init that automatically chooses the 
right type.

Conditions: 
MoveInspect v7.00.xx or higher

SeeAlso:     
gReceiver_GetReferenceModeU, gReceiver_GetReferenceMode
******************************************************************** */
RECEIVER_API UINT gReceiver_GetReferenceModeA(int& iMode, char* pRefName = NULL, int iBufSize = 0);

#ifdef _UNICODE		
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.00.xx or higher

	SeeAlso: gReceiver_GetReferenceModeU, gReceiver_GetReferenceModeA
	******************************************************************** */
	#define gReceiver_GetReferenceMode gReceiver_GetReferenceModeU
#else				
	/* ********************************************************************
	Description: 
	This macro lets your program automatically choose the right kind of 
	string handling. Either ASCII or Unicode.

	Conditions: 
	MoveInspect v7.00.xx or higher

	SeeAlso: gReceiver_GetReferenceModeU, gReceiver_GetReferenceModeA
	******************************************************************** */
	#define gReceiver_GetReferenceMode gReceiver_GetReferenceModeA
#endif

#pragma pack (pop)
}

// ***************************************************************************
#endif